@@ -13,6 +13,8 @@ if sys.version_info < (3,):
     def bytes_to_list(byte_string):
         return [ord(b) for b in byte_string]
 
+    chr_cls = chr
+
 else:
     str_cls = str
     byte_cls = bytes
@@ -20,6 +22,9 @@ else:
 
     bytes_to_list = list
 
+    def chr_cls(num):
+        return bytes([num])
+
 
 def type_name(value):
     """
